@@ -1,11 +1,13 @@
 test_that("cloning repositories works", {
-  skip_if_offline()
+  skip_if_offline('github.com')
   path <- file.path(tempdir(), 'gert')
   repo <- git_clone('https://github.com/r-lib/gert', path = path)
   expect_true(file.exists(file.path(path, 'DESCRIPTION')))
   info <- git_info(repo)
-  expect_equal(info$head, "refs/heads/master")
-  expect_equal(info$shorthand, "master")
+  default_head <- git_remote_ls(repo = repo)$symref[1]
+  default_branch <- basename(default_head)
+  expect_equal(info$head, default_head)
+  expect_equal(info$shorthand, default_branch)
   repo2 <- git_open(path)
   info2 <- git_info(repo2)
   expect_equal(info, info2)
@@ -13,7 +15,7 @@ test_that("cloning repositories works", {
   expect_is(git_log(repo = repo), 'data.frame')
   heads <- git_remote_ls(repo = repo)
   expect_is(heads, 'data.frame')
-  expect_equal(git_remote_info(repo = repo)$head, "refs/remotes/origin/master")
+  expect_equal(git_remote_info(repo = repo)$head, paste0("refs/remotes/origin/", default_branch))
 
   # Test remotes
   remotes <- git_remote_list(repo)
